#+TITLE: Sacha Chua's Emacs configuration
#+ELEVENTY_COLLECTIONS: _posts
#+ELEVENTY_BASE_DIR: ~/proj/static-blog/
#+ELEVENTY_CATEGORIES+: emacs
#+ELEVENTY_LAYOUT: layouts/post
#+ELEVENTY_BASE_URL: https://sachachua.com
* Org Babel, Mermaid JS, and fixing "Failed to launch the browser process" on Ubuntu 24 :org:
:PROPERTIES:
:CUSTOM_ID: mermaid
:EXPORT_DATE: 2025-01-10T14:16:20-0500
:EXPORT_ELEVENTY_PERMALINK: /blog/2025/01/org-babel-mermaid-js-and-fixing-failed-to-launch-the-browser-process-on-ubuntu-24/
:EXPORT_ELEVENTY_FILE_NAME: blog/2025/01/org-babel-mermaid-js-and-fixing-failed-to-launch-the-browser-process-on-ubuntu-24/
:END:

[[https://mermaid.js.org/][Mermaid]] makes pretty diagrams from text. It's
Javascript-based, so the command-line tool (mmdc)
uses Puppeteer to get the results of evaluating
the diagram in the browser. I was running into
some errors trying to get it to work from Org Mode
over [[https://github.com/arnm/ob-mermaid][ob-mermaid]] on Ubuntu 24, since apparently
[[https://github.com/puppeteer/puppeteer/issues/12818][AppArmor restricts Puppeteer]]. ([[https://github.com/mermaid-js/mermaid-cli/issues/730][Error: Failed to
launch the browser process! · Issue #730 ·
mermaid-js/mermaid-cli]]).

I put together a [[https://github.com/arnm/ob-mermaid/pull/33][pull request to modify
ob-mermaid-cli-path]] so that it doesn't get quoted
and can therefore have the aa-exec command needed
to work around that. With that modified
~org-babel-execute:mermaid~, I can then configure
~ob-mermaid~ like this:

#+begin_src emacs-lisp
(use-package ob-mermaid
	:load-path "~/vendor/ob-mermaid")
;; I need to override this so that the executable isn't quoted
(setq ob-mermaid-cli-path "aa-exec --profile chrome mmdc -c ~/.config/mermaid/config.json")
#+end_src

I also ran into a problem where the library that
Emacs uses to display SVGs could not handle the
~foreignObject~ elements used for the labels.
[[https://github.com/mermaid-js/mermaid-cli/issues/112][mermaid missing text in svg · Issue #112 ·
mermaid-js/mermaid-cli]] . Using the following
~~/.config/mermaid/config.json~ fixed it, and I
put the option in the ~ob-mermaid-cli-path~ above
so that it always gets loaded.

#+begin_src js :eval no :comments no :tangle "~/.config/mermaid/config.json"
{
  "flowchart": {
    "useMaxWidth": false,
    "htmlLabels": false
  }
}
#+end_src

Here's sample Mermaid markup and the file it creates:

#+begin_src mermaid :file mermaid-example.svg :exports both
mindmap
  root((test))
    Node 1
      Node 1A
      Node 1B
    Node 2
    Node 3
#+end_src

#+RESULTS:
:results:
[[file:mermaid-example.svg]]
:end:

Now I can see the labeled diagrams inside Emacs, too.

